==> okteta-0.25.5.tar.xz: okteta-0.25.5/libs/kasten/core/io/filesystem/modelencoderfilesystemexportjob.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008-2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "modelencoderfilesystemexportjob.h"
#include "modelencoderfilesystemexportjob_p.h"

namespace Kasten {

ModelEncoderFileSystemExportJob::ModelEncoderFileSystemExportJob(AbstractModel* model,
                                                                 const AbstractModelSelection* selection,
                                                                 const QUrl& url,
                                                                 AbstractModelStreamEncoder* encoder)
    : AbstractFileSystemExportJob(new ModelEncoderFileSystemExportJobPrivate(this, model, selection, url, encoder))
{
}

ModelEncoderFileSystemExportJob::~ModelEncoderFileSystemExportJob() = default;

void ModelEncoderFileSystemExportJob::startExportToFile()
{
    Q_D(ModelEncoderFileSystemExportJob);

    d->startExportToFile();
}

}

==> okteta_0.26.3.orig.tar.xz: okteta-0.26.3/libs/kasten/core/io/filesystem/modelencoderfilesystemexportjob.cpp <==
/*
    This file is part of the Kasten Framework, made within the KDE community.

    Copyright 2008-2009 Friedrich W. H. Kossebau <kossebau@kde.org>

    This library is free software; you can redistribute it and/or
    modify it under the terms of the GNU Lesser General Public
    License as published by the Free Software Foundation; either
    version 2.1 of the License, or (at your option) version 3, or any
    later version accepted by the membership of KDE e.V. (or its
    successor approved by the membership of KDE e.V.), which shall
    act as a proxy defined in Section 6 of version 3 of the license.

    This library is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
    Lesser General Public License for more details.

    You should have received a copy of the GNU Lesser General Public
    License along with this library. If not, see <http://www.gnu.org/licenses/>.
*/

#include "modelencoderfilesystemexportjob.hpp"
#include "modelencoderfilesystemexportjob_p.hpp"

namespace Kasten {

ModelEncoderFileSystemExportJob::ModelEncoderFileSystemExportJob(AbstractModel* model,
                                                                 const AbstractModelSelection* selection,
                                                                 const QUrl& url,
                                                                 AbstractModelStreamEncoder* encoder)
    : AbstractFileSystemExportJob(new ModelEncoderFileSystemExportJobPrivate(this, model, selection, url, encoder))
{
}

ModelEncoderFileSystemExportJob::~ModelEncoderFileSystemExportJob() = default;

void ModelEncoderFileSystemExportJob::startExportToFile()
{
    Q_D(ModelEncoderFileSystemExportJob);

    d->startExportToFile();
}

}
